@@ -1,12 +1,13 @@
 from .scalar_resolver import ScalarResolver
-from ...functional.util import select
 from ...entities.wrappers import KCScalar
-from ...grammar.accessor_grammar import parse_accessor
+from ...functional.util import select
+from ...grammar.accessor_grammar import parse_accessors
+
 
 class InterpolationResolver(ScalarResolver):
     def resolve(self, value, root_node, trace, **__):
-        accessors = parse_accessor(value)
+        accessors = parse_accessors(value)
         node = select(root_node=root_node, accessors=accessors, trace=trace)
         if isinstance(node, KCScalar):
             return node.value
-        return node
\ No newline at end of file
+        return node
